@@ -520,8 +520,11 @@ def diff3(arg1, arg2, arg3, show_graph=0, p=0):
 
 
 def list_inheritable(p=0):
-    import builtins, re
-    x = sorted([i for i in dir(builtins) if not re.search('.*Error|Warning|__|_', i)], key=len)
+    import builtins, re, collections, collections.abc
+    lst = dir(builtins)
+    lst += [f'collections.{i}' for i in dir(collections)]
+    lst += [f'collections.abc.{i}' for i in dir(collections.abc)]
+    x = sorted([i for i in lst if not re.search('.*Error|Warning|__|_', i)], key=len)
     inheritable = []
     non_inheritable = []
     for i in x:
@@ -530,9 +533,23 @@ def list_inheritable(p=0):
             inheritable.append(i)
         except:
             non_inheritable.append(i)
-
     returned_dict = {'inheritable': inheritable, 'non_inheritable': non_inheritable}
     if p == 1:
         pprint(returned_dict, compact=True, width=120)
     else:
-        return returned_dict
\ No newline at end of file
+        return returned_dict
+
+
+def methods_inherited(base_class, p=0):
+    class Base:
+        pass
+
+    class A(base_class):
+        pass
+
+    returned_set = set(dir(A)) - set(dir(Base))
+    if p == 1:
+        from pprint import pprint
+        pprint(returned_set, compact=True, width=120)
+    else:
+        return returned_set
\ No newline at end of file
